-------------------------------------------------------------------------------
--
--  Mod Name : BlinkComboHelper 1.02
--  Author   : Blink
--  Date     : 2016/07/29
--  LastUpdate : 2016/10/02
--
-------------------------------------------------------------------------------

local addonName = "BlinkComboHelper"
local addon = {}
local animations = {}
_G[addonName] = addon



-------------------------------------------------------------------------------
-- local variables
-------------------------------------------------------------------------------

local BASE_FONT_SIZE = 70
local UPDATE_INTERVAL = 0.1

local frameOnUpdate
local frameOnEvent
local fadeSide = -1 -- 사라지는 방향
local fontPath = [[Fonts\K_Pagetext.TTF]]

local function updateFunc(frame, alpha, size, x, y)
	frame:SetAlpha(alpha);
	frame.combo:SetTextHeight(size);
	frame:SetPoint("CENTER", "UIParent", "CENTER", x, y );
end

function animations:pop()
	SetUpAnimation(addon.frame, {
		totalTime = 1.0,
		updateFunc = updateFunc,
		getPosFunc = function (self, fraction)
			if fraction < 0.15 then
				local f = fraction / 0.15
				return f, BASE_FONT_SIZE * f + 1, 0, BASE_FONT_SIZE*f
			elseif fraction < 0.5 then
				return 1.0, BASE_FONT_SIZE + 1, 0, BASE_FONT_SIZE
			else
				local f = (fraction-0.5) / 0.5
				local alpha = 1.0-f;
				if alpha<0 then
					alpha = 0
				end
				return alpha, BASE_FONT_SIZE * alpha + 1, f*fadeSide*20, BASE_FONT_SIZE
			end
		end,
	},function(self)
		fadeSide = fadeSide * -1
	end)
end


function addon:CreateFrames()
	
	self.frame:ClearAllPoints()
	self.frame:SetPoint("CENTER", 0, 60)
	self.frame:SetFrameStrata("BACKGROUND")
	self.frame:SetFrameLevel(0)

	self.frame.combo = self.frame:CreateFontString(nil, "OVERLAY")
	self.frame.combo:SetFont(fontPath, BASE_FONT_SIZE, "THICKOUTLINE")
	self.frame.combo:SetPoint("CENTER", self.frame)
	self.frame.combo:SetAlpha(1.0)
	self.frame.combo:SetJustifyH("CENTER")
	self.frame.combo:SetTextColor(0.1, 1.0, 0.1);

	self.frame:SetHeight(self.frame.combo:GetHeight())
	self.frame:SetWidth(50)
end

function frameOnEvent(self, event, ...)
	if ( event == "PLAYER_LOGIN" ) then
		--self:UnregisterEvent("PLAYER_LOGIN");
		self:Hide();

		self.delayedUpdate = 0
		addon.class = select(2, UnitClass("player"))

		if locale == 'koKR' then
			fontPath = [[Fonts\K_Pagetext.TTF]]
		elseif locale == "zhCN" then
			-- someone from zhCN please adjust if needed
			fontPath = [[Fonts\ARHei.ttf]]
		elseif locale == "zhTW" then
			-- someone from zhTW please adjust if needed
			fontPath = [[Fonts\bLEI00D.ttf]]
		elseif locale == "ruRU" then
			fontPath = [[Fonts\K_Pagetext.TTF]]
		else
			fontPath = [[Fonts\K_Pagetext.TTF]]
		end

		addon:CreateFrames()

	elseif event == "PLAYER_REGEN_DISABLED" then
		self.inCombat = true
		self:Show();
		self:SetScript("OnUpdate", frameOnUpdate)

	elseif event == "PLAYER_REGEN_ENABLED" then
		self.inCombat = false
		self:Hide();
		self:SetScript("OnUpdate", nil)
	end
end


function frameOnUpdate(self, elapsed)
	self.delayedUpdate = self.delayedUpdate + elapsed
	if self.delayedUpdate > UPDATE_INTERVAL then
		self.delayedUpdate = 0
		addon:updateCombo();
	end
end

function addon:updateCombo()

	local combo = 0

	if self.class == "ROGUE" or self.class == "DRUID" then
		combo = GetComboPoints("player", "target")
	elseif self.class == "PALADIN" then
		combo = UnitPower( "player", SPELL_POWER_HOLY_POWER );
	elseif self.class == "MAGE" then
		combo = UnitPower("player", SPELL_POWER_ARCANE_CHARGES, true)
	elseif self.class == "MONK" and GetSpecialization()==3 then
		combo = UnitPower( "player", SPELL_POWER_CHI )
	elseif self.class == "WARLOCK" then
		combo = UnitPower( "player", SPELL_POWER_SOUL_SHARDS )
	elseif self.class == "DEATHKNIGHT" and GetSpecialization()==1 then
		local name, _ = GetSpellInfo(195181) -- Bone Shield
		combo, _ = select(4, UnitBuff("player", name)) or 0
	else
		self.lastCombo = combo
		return
	end

	if combo > 0 and combo~=self.lastCombo then
		self.frame.combo:SetText(combo)
		animations:pop()
	end
	self.lastCombo = combo
end


addon.frame = CreateFrame("Frame")
addon.frame:RegisterEvent("PLAYER_REGEN_DISABLED")
addon.frame:RegisterEvent("PLAYER_REGEN_ENABLED")
addon.frame:RegisterEvent("PLAYER_LOGIN")
addon.frame:SetScript("OnEvent", frameOnEvent)
